utils/format_text library
Functions
-
formatText(
String fullText) → List< Map> - split text enclosed in pattern into a list if needed
-
splitAllPattern(
String text) → List< String> - split all pattern in text into a list of strings
-
splitText(
String pattern, List< String> formattedText) → List<String> - split text into a list of strings when having a pattern